@@ -9,20 +9,20 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.1.") or
-    raise "ruby lib version (3.1.5) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.3.") or
+    raise "ruby lib version (3.3.6) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.1.0/i386-mingw32")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3.0/i386-mingw32")
   # DESTDIR on make install.
   DESTDIR = TOPDIR && TOPDIR[/\A[a-z]:/i] || '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "1"
-  CONFIG["TEENY"] = "5"
-  CONFIG["PATCHLEVEL"] = "252"
+  CONFIG["MINOR"] = "3"
+  CONFIG["TEENY"] = "6"
+  CONFIG["PATCHLEVEL"] = "108"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ".exe"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/mingw32")
@@ -30,7 +30,7 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "msvcrt-$(RUBY_BASE_NAME)$(MAJOR)$(MINOR)0"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.1.pc"
+  CONFIG["ruby_pc"] = "ruby-3.3.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/mingw32' '--build=i686-w64-mingw32' '--host=i686-w64-mingw32' '--target=i686-w64-mingw32' '--disable-werror' 'build_alias=i686-w64-mingw32' 'host_alias=i686-w64-mingw32' 'target_alias=i686-w64-mingw32' 'CC=gcc' 'CXX=g++' 'CFLAGS=-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -I/mingw32/include/pdcurses ' 'LDFLAGS=-Wl,--no-seh -Wl,--large-address-aware' 'CPPFLAGS=-D__USE_MINGW_ANSI_STDIO=1 -DFD_SETSIZE=2048  -I/mingw32/include/pdcurses' 'CXXFLAGS=-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -I/mingw32/include/pdcurses '"
+  CONFIG["configure_args"] = " '--prefix=/mingw32' '--build=i686-w64-mingw32' '--disable-install-doc' '--with-setjmp-type=setjmp' 'build_alias=i686-w64-mingw32' 'CC=gcc' 'CXX=g++' 'CFLAGS=-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-incompatible-pointer-types' 'LDFLAGS=-Wl,--no-seh -Wl,--large-address-aware' 'CPPFLAGS=' 'CXXFLAGS=-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.1.0"
+  CONFIG["ruby_version"] = "3.3.0"
   CONFIG["sitearch"] = "i386-msvcrt"
   CONFIG["arch"] = "i386-mingw32"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -73,6 +73,7 @@ module RbConfig
   CONFIG["MAKEFILES"] = "Makefile GNUmakefile"
   CONFIG["USE_LLVM_WINDRES"] = "no"
   CONFIG["PLATFORM_DIR"] = "win32"
+  CONFIG["COROUTINE_TYPE"] = "win32"
   CONFIG["THREAD_MODEL"] = "win32"
   CONFIG["SYMBOL_PREFIX"] = "_"
   CONFIG["EXPORT_PREFIX"] = " "
@@ -89,22 +90,28 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "lib$(RUBY_SO_NAME).dll.a"
   CONFIG["LIBRUBY_ALIASES"] = ""
-  CONFIG["LIBRUBY_SONAME"] = "lib$(RUBY_SO_NAME).$(SOEXT).$(RUBY_API_VERSION)"
+  CONFIG["LIBRUBY_SONAME"] = ""
   CONFIG["LIBRUBY_SO"] = "$(RUBY_SO_NAME).dll"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = "$(RUBYW_BASE_NAME)"
   CONFIG["rubyw_install_name"] = "$(RUBYW_INSTALL_NAME)"
   CONFIG["EXTDLDFLAGS"] = "$(DEFFILE)"
   CONFIG["EXTLDFLAGS"] = "-static-libgcc"
-  CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wwrite-strings -Wold-style-definition -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable -Wundef"
+  CONFIG["strict_warnflags"] = ""
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdiv-by-zero -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wold-style-definition -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable -Wmisleading-indentation -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-omit-frame-pointer -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
+  CONFIG["RJIT_SUPPORT"] = "no"
+  CONFIG["YJIT_OBJ"] = ""
+  CONFIG["YJIT_LIBS"] = ""
+  CONFIG["CARGO_BUILD_ARGS"] = ""
+  CONFIG["YJIT_SUPPORT"] = "no"
+  CONFIG["CARGO"] = ""
+  CONFIG["RUSTC"] = "no"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
-  CONFIG["MJIT_SUPPORT"] = "yes"
   CONFIG["EXECUTABLE_EXTS"] = ".exe .com .cmd .bat"
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "yes"
@@ -114,8 +121,6 @@ module RbConfig
   CONFIG["TEST_RUNNABLE"] = "yes"
   CONFIG["rubylibprefix"] = "$(libdir)/$(RUBY_BASE_NAME)"
   CONFIG["setup"] = "Setup"
-  CONFIG["ENCSTATIC"] = ""
-  CONFIG["EXTSTATIC"] = ""
   CONFIG["SOEXT"] = "dll"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = ""
@@ -124,6 +129,8 @@ module RbConfig
   CONFIG["LIBPATHFLAG"] = " -L%s"
   CONFIG["LINK_SO"] = ""
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
+  CONFIG["ENCSTATIC"] = ""
+  CONFIG["EXTSTATIC"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT"] = "so"
@@ -142,16 +149,16 @@ module RbConfig
   CONFIG["POSTLINK"] = ":"
   CONFIG["incflags"] = ""
   CONFIG["WERRORFLAG"] = "-Werror"
+  CONFIG["RUBY_DEVEL"] = ""
   CONFIG["CHDIR"] = "cd"
   CONFIG["RMALL"] = "rm -fr"
   CONFIG["RMDIRS"] = "rmdir --ignore-fail-on-non-empty -p"
   CONFIG["RMDIR"] = "rmdir --ignore-fail-on-non-empty"
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
-  CONFIG["PKG_CONFIG"] = "i686-w64-mingw32-pkg-config"
-  CONFIG["DOXYGEN"] = "doxygen"
-  CONFIG["DOT"] = "dot"
-  CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
+  CONFIG["PKG_CONFIG"] = "pkg-config"
+  CONFIG["DOXYGEN"] = ""
+  CONFIG["DOT"] = ""
   CONFIG["MKDIR_P"] = "/usr/bin/mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
   CONFIG["INSTALL_SCRIPT"] = "$(INSTALL)"
@@ -163,9 +170,8 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc.exe (Rev6, Built by MSYS2 project) 13.2.0\nCopyright (C) 2023 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc.exe (Rev2, Built by MSYS2 project) 14.2.0\nCopyright (C) 2024 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
-  CONFIG["MJIT_CC"] = "D:/a/msys64/mingw32/bin/gcc.exe"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
@@ -173,29 +179,31 @@ module RbConfig
   CONFIG["GNU_LD"] = "yes"
   CONFIG["GCC"] = "yes"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -I/mingw32/include/pdcurses "
+  CONFIG["CXXFLAGS"] = "-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-D__USE_MINGW_ANSI_STDIO=1 -DFD_SETSIZE=2048  -I/mingw32/include/pdcurses -D_WIN32_WINNT=0x0600 -D__MINGW_USE_VC2005_COMPAT $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -Wl,--no-seh -Wl,--large-address-aware -Wl,--no-as-needed"
-  CONFIG["CFLAGS"] = "-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -I/mingw32/include/pdcurses "
+  CONFIG["CPPFLAGS"] = "-D_WIN32_WINNT=0x0600 -D__MINGW_USE_VC2005_COMPAT $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -Wl,--no-seh -Wl,--large-address-aware -fstack-protector-strong -Wl,--no-as-needed"
+  CONFIG["CFLAGS"] = "-march=pentium4 -mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong -Wp,-D__USE_MINGW_ANSI_STDIO=1 -Wno-incompatible-pointer-types"
   CONFIG["STRIP"] = "strip -S -x"
-  CONFIG["RANLIB"] = "i686-w64-mingw32-gcc-ranlib"
+  CONFIG["RANLIB"] = "gcc-ranlib"
   CONFIG["OBJDUMP"] = "objdump"
   CONFIG["OBJCOPY"] = ":"
-  CONFIG["NM"] = "i686-w64-mingw32-gcc-nm"
+  CONFIG["NM"] = "gcc-nm"
   CONFIG["LD"] = "ld"
   CONFIG["CXX"] = "g++"
   CONFIG["AS"] = "as"
-  CONFIG["AR"] = "i686-w64-mingw32-gcc-ar"
+  CONFIG["AR"] = "gcc-ar"
   CONFIG["CC"] = "gcc"
+  CONFIG["wasmoptflags"] = ""
+  CONFIG["WASMOPT"] = ""
   CONFIG["target_os"] = "mingw32"
   CONFIG["target_vendor"] = "w64"
   CONFIG["target_cpu"] = "i386"
-  CONFIG["target"] = "i386-w64-mingw32"
-  CONFIG["host_os"] = "mingw32"
-  CONFIG["host_vendor"] = "w64"
-  CONFIG["host_cpu"] = "i686"
-  CONFIG["host"] = "i686-w64-mingw32"
+  CONFIG["target"] = "$(target_cpu)-$(target_vendor)-$(target_os)"
+  CONFIG["host_os"] = "$(target_os)"
+  CONFIG["host_vendor"] = "$(target_vendor)"
+  CONFIG["host_cpu"] = "$(target_cpu)"
+  CONFIG["host"] = "$(target)"
   CONFIG["build_os"] = "mingw32"
   CONFIG["build_vendor"] = "w64"
   CONFIG["build_cpu"] = "i686"
@@ -210,8 +218,9 @@ module RbConfig
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
-  CONFIG["target_alias"] = "i386-w64-mingw32"
-  CONFIG["host_alias"] = "i686-w64-mingw32"
+  CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
+  CONFIG["target_alias"] = ""
+  CONFIG["host_alias"] = "$(target_alias)"
   CONFIG["build_alias"] = "i686-w64-mingw32"
   CONFIG["LIBS"] = "-lshell32 -lws2_32 -liphlpapi -limagehlp -lshlwapi -lbcrypt "
   CONFIG["ECHO_T"] = ""
@@ -247,8 +256,8 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "13.0.0"
-  CONFIG["UNICODE_EMOJI_VERSION"] = "13.1"
+  CONFIG["UNICODE_VERSION"] = "15.0.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "15.0"
   CONFIG["platform"] = "$(arch)"
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
@@ -309,7 +318,6 @@ module RbConfig
     RbConfig::expand(val)
   end
 
-  # :nodoc:
   # call-seq:
   #
   #   RbConfig.fire_update!(key, val)               -> array
@@ -325,7 +333,7 @@ module RbConfig
   #   RbConfig::CONFIG.values_at("CC", "LDSHARED")          # => ["gcc-8", "gcc-8 -shared"]
   #
   # returns updated keys list, or +nil+ if nothing changed.
-  def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG)
+  def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG) # :nodoc:
     return if mkconf[key] == val
     mkconf[key] = val
     keys = [key]
